@@ -7,50 +7,51 @@ ConfigFile="SleepAnalyser.conf"
 devconfigfolder="/home/gruinelli/Maemo/SleepAnalyser/"
 devlogfolder="/tmp/"
 
+dateformat="%Y-%m-%d %H:%M:%S"
 
 #init values
-sampling=1000 #in milliseconds
-sample_index=0
-sample_smoothing=10 #value_smoothing at 1. level
-value_smoothing=10 #value_smoothing at 2. level
-derivation=5 #shift in derivation
+Sampling_interval=1000 #in milliseconds
+Sample_index=0
+Sample_smoothing=10 #value_smoothing at 1. level
+Value_smoothing=10 #value_smoothing at 2. level
+Derivation=5 #shift in Derivation
 Ysize=121 #default value Y scale in px
 Yscale=1 #default value Y stretching
 arrXscale=[1, 4, 6] #scaling steps X accis
 arrXscaleLen=3
 Xscale=1 #default value X scale in arraXscale index
 
-value_index=0
-values_total=0
+Value_index=0
+Values_total=0
 
 arrLogFiles=[]
 arrLogFileIndex=0
 
-trigger=14 #trigger level for movement
-maxtrigger=100
+Trigger=14 #Trigger level for movement
+maxTrigger=100
 
 demo=0
 debug=0
-test=0
+#test=0
 logfilename=""
 logfile=""
 logfolder=""
 lastlogfile=""
-Note=""
-Header=""
-StartTime=0
-StartTimeSec=0
-StopTime=0
-MidnightTransitions=0
-ChangesInGraph=0
+#Note=""
+#Header=""
+#StartTime=0
+#StartTimeSec=0
+#StopTime=0
+#MidnightTransitions=0
+ChangesInGraph=False
 run=0
-QuickMode=0
+QuickMode=False
 version="0"
 build="0"
 user=""
 app_path="./"
-passed_time=0
-passed_time2=0
+#passed_time=0
+#passed_time2=0
 DelayStartTime=10
 #DropIndexes=0
 last_beep=0
@@ -62,11 +63,11 @@ interval=0
 GraphStart=0
 #GraphStartHours=0
 #GraphStartMinutes=0
-AlarmTimeSec=0 #absolute alarm time in seconds
-AlarmDate=0
+#AlarmTimeSec=0 #absolute alarm time in seconds
+#AlarmDate=0
 AlarmHour=-1
 AlarmMinute=-1
-AlarmIsSet=False
+#AlarmIsSet=False
 AlarmIsActive=False
 AlarmTimeWindow=30 #in minutes
 AlarmID=-1 #cookie for communication to system
@@ -75,12 +76,14 @@ AlarmID=-1 #cookie for communication to system
 
 #arrays, indexes, lenghts
 #arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
-arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
-##old             [0]=time            [1]=X,                [2]=Y,                [3]=X derivation,[4]=Y derivation
-#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y derivation, [4]=Time since last movement over treshhold, [5]=event
-arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen] 
+#arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
+##old             [0]=time            [1]=X,                [2]=Y,                [3]=X Derivation,[4]=Y Derivation
+#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
+#arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen] 
 arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
 arrDataIndex=0
 arrLogFiles=[]
 arrLogFilesIndex=0
 LogFileSelectedDate=""
+
+#LastIndex=-1
