@@ -74,8 +74,8 @@ def DeleteAlarm():
     else:
         print "* No alarm to be deleted"        
 
-    records.AlarmIsSet=False
-    records.AlarmIsActive=False
+#    records.AlarmIsSet=False
+    data.AlarmIsActive=False
 
 
 
@@ -89,8 +89,7 @@ def ProcessAlarm():
     if(peak>data.Trigger): #big Movement
        if(records.AlarmIsSet==True and data.AlarmIsActive==False and now>=records.AlarmTimeWindowStart_seconds and now<records.AlarmTimeWindowEnd_seconds):
             #print big movement and we are in alarm time window, update alarm time, set alarm off
-            print "************ ALARM ALARM *********************"
-            data.AlarmIsActive=True
+            print "************ ALARM ALARM (Movement) *********************"
             DeleteAlarm() #delete old alarm if existing
 #            h=int(strftime("%H", time.localtime()))
 #            m=int(strftime("%M", time.localtime()))
@@ -100,10 +99,17 @@ def ProcessAlarm():
             records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple) 
             SetAlarm() #set alarm to go off now
             records.Trigger=data.Trigger #update Trigger level on alarm occurence
+            data.AlarmIsActive=True
     elif(now>=records.AlarmTimeWindowEnd_seconds): #End of alarm time window, set alarm off anyway
         if(records.AlarmIsSet==True and data.AlarmIsActive==False): #Alarm is set and not active yet
-            print "************ ALARM ALARM *********************"
-            data.AlarmIsActive=True
+            print "************ ALARM ALARM (End of Alarm Time Window) *********************"
             records.AlarmTime_tuple=time.localtime()#set to now (just for record)
             records.AlarmTime_seconds=Tuple2Seconds(records.AlarmTime_tuple) 
-            records.Trigger=data.Trigger #update Trigger level on alarm occurence
\ No newline at end of file
+            records.Trigger=data.Trigger #update Trigger level on alarm occurence
+            data.AlarmIsActive=True
+
+#    print "records.AlarmIsSet", records.AlarmIsSet 
+#    print "data.AlarmIsActive:",  data.AlarmIsActive
+#    print ""
+            
+            
