@@ -56,6 +56,7 @@ def CreateRecordFile(interval):
 
 
 def CreateHeader():
+    if(records.SWversion<1.6): records.SWversion=1.6 #update file version sas header gets saved in new version
     h=" , , , User: " + str(records.User)+ \
         ", SW version: " + str(records.SWversion)+ \
         ", Sampling interval: " + str(records.Sampling_interval)+ \
@@ -152,68 +153,85 @@ def LoadRecord():
     try: #read header data
        #process header line 1
         tmp=file.readline()
-#        print tmp
+    #        print tmp
         header=string.split(tmp, ", ")
         records.SWversion=float(string.replace(header[4], "SW version:",  ""))
-        if(records.SWversion<1.6):
-            print "Sorry, records older than SW version 1.6 are not compatible."
-            records.status="File version not compatible"
-            records.statusID="VERSION_INCOMPATIBLE"
-            file.close()
-            return 9    
-        records.User=header[3]
-        records.Sampling_interval=int(string.replace(header[5], "Sampling interval:",  ""))
-        records.Sample_smoothing=int(string.replace(header[6], "Sample smoothing:",  ""))
-        records.Value_smoothing=int(string.replace(header[7], "Value smoothing:",  ""))
-        records.Trigger=int(string.replace(header[8], "Trigger level:",  ""))
-        
-       #process header line 2
-        tmp=file.readline()
-#        print tmp
-        tmp=string.replace(tmp[:-1], "Start time: ",  "")
-        records.StartTime_tuple=time.strptime(tmp,  data.dateformat)
-        records.StartTime_seconds=Tuple2Seconds( records.StartTime_tuple)
-            
-       #process header line 3
-        tmp=file.readline()
-#        print tmp
-        if(tmp!="No alarm set\n"):
-            print "An alarm is set"
-            records.AlarmIsSet=True
-            tmp=string.replace(tmp[:-1], "Alarm: ",  "")
-            records.AlarmTime_tuple=time.strptime(tmp,  data.dateformat)
-            records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
+        if(records.SWversion<1.6): #workaround for old files
+            print "Record is older than SW version 1.6, use old protocol"
+    #            print "Sorry, records older than SW version 1.6 are not compatible."
+    #            records.status="File version not compatible"
+    #            records.statusID="VERSION_INCOMPATIBLE"
+    #            file.close()
+    #            return 9    
+            records.User=header[3]
+            Startdate_date=string.replace(header[5], "Date:",  "")
+            x=string.replace(header[6], "Sampling interval:",  "")
+            records.Sampling_interval=int(string.replace(x, " ms",  ""))
+            records.Sample_smoothing=int(string.replace(header[7], "sampling smoothing:",  ""))
+            records.Value_smoothing=int(string.replace(header[8], "value_smoothing:",  ""))
+            records.Trigger=30
         else:
-            print "No alarm is set"
+            records.User=header[3]
+            records.Sampling_interval=int(string.replace(header[5], "Sampling interval:",  ""))
+            records.Sample_smoothing=int(string.replace(header[6], "Sample smoothing:",  ""))
+            records.Value_smoothing=int(string.replace(header[7], "Value smoothing:",  ""))
+            records.Trigger=int(string.replace(header[8], "Trigger level:",  ""))
         
-       #process header line 4
-        tmp=file.readline()
-#        print tmp
-        if(records.AlarmIsSet==True): 
-            tmp=string.replace(tmp[:-1], "Alarm Time Window Start: ",  "")
-            records.AlarmTimeWindowStart_tuple=time.strptime(tmp,  data.dateformat)
-            records.AlarmTimeWindowStart_seconds=Tuple2Seconds(records.AlarmTimeWindowStart_tuple)
         
-       #process header line 5
-        tmp=file.readline()
-#        print tmp
-        if(records.AlarmIsSet==True): 
-            tmp=string.replace(tmp[:-1], "Alarm Time Window End: ",  "")
-            records.AlarmTimeWindowEnd_tuple=time.strptime(tmp,  data.dateformat)
-            records.AlarmTimeWindowEnd_seconds=Tuple2Seconds( records.AlarmTimeWindowEnd_tuple)
-            records.AlarmTimeWindow_minutes=int((records.AlarmTimeWindowEnd_seconds-records.AlarmTimeWindowStart_seconds)/60)
-        
-       #process header line 6
-        tmp=file.readline()
-        records.Note=string.replace(tmp[:-1], "Note: ",  "")
-        
-      #process header line 7
-        tmp=file.readline()  #not used, column header
+        if(records.SWversion<1.2): #workaround for old files
+            records.Notes=""
+        elif(records.SWversion<1.6): #workaround for old files
+            #process header line 2
+            tmp=file.readline()
+            records.Note=string.replace(tmp[:-1], "Note: ",  "")    
+        else:
+           #process header line 2
+            tmp=file.readline()
+    #        print tmp
+            tmp=string.replace(tmp[:-1], "Start time: ",  "")
+            records.StartTime_tuple=time.strptime(tmp,  data.dateformat)
+            records.StartTime_seconds=Tuple2Seconds( records.StartTime_tuple)
+                
+           #process header line 3
+            tmp=file.readline()
+    #        print tmp
+            if(tmp!="No alarm set\n"):
+                print "An alarm is set"
+                records.AlarmIsSet=True
+                tmp=string.replace(tmp[:-1], "Alarm: ",  "")
+                records.AlarmTime_tuple=time.strptime(tmp,  data.dateformat)
+                records.AlarmTime_seconds=Tuple2Seconds( records.AlarmTime_tuple)
+            else:
+                print "No alarm is set"
+            
+           #process header line 4
+            tmp=file.readline()
+    #        print tmp
+            if(records.AlarmIsSet==True): 
+                tmp=string.replace(tmp[:-1], "Alarm Time Window Start: ",  "")
+                records.AlarmTimeWindowStart_tuple=time.strptime(tmp,  data.dateformat)
+                records.AlarmTimeWindowStart_seconds=Tuple2Seconds(records.AlarmTimeWindowStart_tuple)
+            
+           #process header line 5
+            tmp=file.readline()
+    #        print tmp
+            if(records.AlarmIsSet==True): 
+                tmp=string.replace(tmp[:-1], "Alarm Time Window End: ",  "")
+                records.AlarmTimeWindowEnd_tuple=time.strptime(tmp,  data.dateformat)
+                records.AlarmTimeWindowEnd_seconds=Tuple2Seconds( records.AlarmTimeWindowEnd_tuple)
+                records.AlarmTimeWindow_minutes=int((records.AlarmTimeWindowEnd_seconds-records.AlarmTimeWindowStart_seconds)/60)
+            
+           #process header line 6
+            tmp=file.readline()
+            records.Note=string.replace(tmp[:-1], "Note: ",  "")
+            
+          #process header line 7
+            tmp=file.readline()  #not used, column header
         
         print "Record header successful read"
     except:
         print "Record header data corrupt"
-        records.status="File header corrupted"
+        records.status="File header corrupted or not compatible"
         records.statusID="HEADER_CORRUPTED"
 #        print sys.exc_info() 
         file.close()
@@ -224,25 +242,28 @@ def LoadRecord():
     records.Index=0
     try: #get data
         for line in file:
-#            print line
+    #            print line
             d=string.split(line[:-1],  ", ")
-#                print len(d)
+    #                print len(d)
             records.arrData[0][records.Index]=d[0] #time
             records.arrData[1][records.Index]=int(d[1]) #X
             records.arrData[2][records.Index]=int(d[2]) #Y
-            records.arrData[5][records.Index]=d[3] #Event
-#           
+            try:
+                records.arrData[5][records.Index]=d[3] #Event
+            except:
+                pass
+    #           
             records.Index=records.Index+1            
             if(records.Index==records.MaxArrayDataLen-1): 
                 print "Stopped, array is full, file is to big. Loaded ",  records.Index,  "lines"                
-                records.status="Array full"
+                records.status="Data Array is full (max "+str(records.MaxArrayDataLen)+ " entries)"
                 records.statusID="ARRAY_FULL"
-#                file.close()
-#                return 7 #File to long
+    #                file.close()
+    #                return 7 #File to long
                 break
     except:
         print "File is corrupted"
-        records.status="File is corrupted"
+        records.status="File is corrupted or not compatible"
         records.statusID="FILE_CORRUPTED"
         file.close()
         return 3 #corrupted file
@@ -251,9 +272,15 @@ def LoadRecord():
         
     if(records.Index==0):
         print "No movement data in record"
-        records.status="No data in file"
+        records.status="No movement data in file to be shown"
         records.statusID="NO_DATA"
         return 4
+        
+        
+    if(records.SWversion<1.6): #workaround for old files
+        if(records.Index>0): records.StartTime_tuple=time.strptime(Startdate_date+" "+str(records.arrData[0][0]),  " %d-%m-%Y %H:%M:%S") #no data anyway
+        else: records.StartTime_tuple=time.strptime(Startdate_date+" 00:00:00",  " %d-%m-%Y %H:%M:%S") #no data anyway
+        records.StartTime_seconds=Tuple2Seconds(records.StartTime_tuple)
 
     print "Loaded successful",  records.Index, "lines"
     if(records.AlarmIsSet==True): 
@@ -261,9 +288,10 @@ def LoadRecord():
         print "But will show up to index",  records.LastIndex,  "as the AlarmTimeWindow ends there"
     else: records.LastIndex=records.Index
         
-    PrintRecordData(False)
     records.status="Data successful loaded"
     records.statusID="OK"
+    
+    PrintRecordData(False)
     return 0 #all ok
     
     
