@@ -485,7 +485,8 @@ class frmRecordWindow(QMainWindow):
             
 
     def UpdateScreenStart(self):
-        t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
+#        t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
+        t=strftime("%a, %x %X", data.StartTime)
         self.ui.lblStarttime.setText(t)
         self.ui.lblElapsedTime.setText("")
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
@@ -510,7 +511,8 @@ class frmRecordWindow(QMainWindow):
         if(data.run==2): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
-            d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
+#            d=time.strftime("%H:%M:%S", time.gmtime(time_difference))
+            d=time.strftime("%X", time.gmtime(time_difference))
             self.ui.lblElapsedTime.setText(d + " ("+str(records.Index)+" entries)")
         
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -667,13 +669,17 @@ class frmViewWindow(QMainWindow):
 #        self.ui.lblLogfile.setText(data.logfilename+" (in "+shortfolder+")")
         self.ui.lblLogfile.setText(data.logfilename)
 
-        d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
+#        d0=strftime("%a. %d.%m.%Y  %H:%M:%S", records.StartTime_tuple)
+        d0=strftime("%a. %x %X", records.StartTime_tuple)
         EndTime_tuple=Seconds2Tuple(Tuple2Seconds(records.StartTime_tuple)+records.Index*records.Sampling_interval*records.Value_smoothing/1000)
         if(strftime("%d.%m.%Y", records.StartTime_tuple)==strftime("%d.%m.%Y", EndTime_tuple)):
-            d1=strftime("%H:%M:%S", EndTime_tuple) #on same day, only show date once
+#            d1=strftime("%H:%M:%S", EndTime_tuple) #on same day, only show date once
+#        else:
+#            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
+            d1=strftime("%X", EndTime_tuple) #on same day, only show date once
         else:
-            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", EndTime_tuple) 
-        
+            d1=strftime("%a. %x %X", EndTime_tuple) 
+            
         diff_sec=records.Index*records.Sampling_interval*records.Value_smoothing/1000
         diff_tuple=Seconds2Tuple(diff_sec)
         diff=strftime("%H:%M:%S", EndTime_tuple)
@@ -928,7 +934,7 @@ class frmViewWindow(QMainWindow):
         "Sampling smoothing: "+str(records.Sample_smoothing) + ", " + \
         "Value smoothing: "+str(records.Value_smoothing) + ", " + \
         "Trigger level: "+str(records.Trigger) + "\n" + \
-        "Created with SleepAnalyser version "+str(records.SWversion))
+        "Record version "+str(records.SWversion))
         
 
 
@@ -1057,10 +1063,12 @@ class frmAlarmTimeWindow(QMainWindow):
         QMainWindow.__init__(self, parent) # Notice that you must give a parent window as parameter to the constuctor
         
         if(data.demo==False): self.setAttribute(Qt.WA_Maemo5StackedWindow) # Also set the Stacked Window parameter for every subwindow in the stack
-        
+#        self.setWindowFlags(Qt.SplashScreen)   
         self.ui = Ui_AlarmTimeWindow()
         self.ui.setupUi(self)
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+        
+
 
         QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
                 
@@ -1189,6 +1197,7 @@ class frmAskForKeepWindow(QMainWindow):
         
 
     def KeepRecord(self):
+        print "Stop recording and keep record"
         global ViewWindow
         StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
@@ -1203,6 +1212,7 @@ class frmAskForKeepWindow(QMainWindow):
 
 
     def RemoveRecord(self): #removed record
+        print "Stop recording and remove record"
         global StartWindow,  RecordWindow
         StopMeasurement()
         DeleteAlarm() #delete Alarm if existing
@@ -1215,13 +1225,15 @@ class frmAskForKeepWindow(QMainWindow):
 
 
 
-    def ContinueRecording(self):
+    def ContinueRecording(self):        
+        print "continue recording"
         self.hide()
         return
 
     def closeEvent(self, event):        
         event.ignore() #do not close
 
+        self.KeepRecord() #interprete closing as "stop and keep file"
 
 
 
